@@ -178,7 +178,7 @@ class HttpClient(object):
         return self._timeout
 
     @timeout.setter
-    def timeout_setter(self, value):
+    def timeout(self, value):
         self._timeout = value
         if self.client:
             self.client.timeout = value
